Learn R Programming

tidyestimate (version 1.1.1)

gene_sets: Gene sets to infer tumor stromal and immune infiltration

Description

Two gene sets, each 141 genes in length, created to infer stromal and immune infiltration

Usage

gene_sets

Arguments

Format

A data frame with 141 row and 2 variables:

stromal_signature

Geneset of HGNC symbols used to infer tumor stromal cell infiltration

immune_signature

Geneset of HGNC symbols used to infer tumor immune cell infiltration